Description: Python Pyjamas Examples
Keywords: Python Pyjamas Examples, Python Web widgets

# Pyjamas Examples

#### Demos are enabled once built.

## Addons Gallery

### Demo gallery of addon components

- (demo) AddonsGallery

#### source directory (addonsgallery)

## Ajaxlib Test

### Experimental Dynamic Module loading of a Javascript Module

- (demo) AjaxTest

#### source directory (ajaxlibtest)

## Anchor

### Demonstration of an external link

- (demo) Anchor

#### source directory (anchor)

## Asteroids

### Asteroids game example

- (demo) Space

#### source directory (asteroids)

## Browser Detect

### Demo of browser-specific coding

- (demo) BrowserDetect

#### source directory (browserdetect)

## Builder

### Use the xml of pyjsglade to dynamically create interface elements

- (demo) Builder

#### source directory (builder)

## Canvas Processing

### Canvas Processing Example

- (demo) CanvasProcessing

#### source directory (canvasprocessing)

## Clickable RootPanel

### Propagation of events

- (demo) ClickableRootPanel

#### source directory (clickablerootpanel)

## Click Override

### Filter or ignore onBrowserEvent

- (demo) Override

#### source directory (clickoverride)

## Controls

### Controls Tutorial

- (demo) ControlDemo

#### source directory (controls)

## CSS Messer

### Change css contents on the fly

- (demo) CSSMess

#### source directory (cssmesser)

## DateField

### Calendar usage

- (demo) DateField

#### source directory (datefield)

## Drag and Drop Tests

### Several tests of pyjamas drag and drop

- (demo) DNDTest

#### source directory (dnd)

## Dynamic Table

### Port of GWT dynamic table example

- (demo) DynaTable

#### source directory (dynamictable)

## Employee Admin

### PureMVC employee admin example

- (demo) EmployeeAdmin

#### source directory (employeeadmin)

## Flow Panel

### (unknown)

- (demo) FlowPanel

#### source directory (flowpanel)

## Form Panel

### FormPanel example

- (demo) FormPanelExample

#### source directory (formpanel)

## Sorted Grid Thing

### (unknown)

- (demo) SortedGridThing

#### source directory (funnysortedgridthing)

## GChart Test

### Port of GChart Example

- (demo) GChartTestApp

#### source directory (gcharttestapp)

## getattr

### Example getattr() use

- (demo) MainTest

#### source directory (getattr)

## Google Maps Example

### Python wrapper around the GMaps JS API

- (demo) MapSimple
- (demo) ControlDisableUI
- (demo) ControlOptions
- (demo) ControlSimple
- (demo) DirectionsSimple
- (demo) EventArguments
- (demo) EventClosure
- (demo) EventProperties
- (demo) EventSimple
- (demo) GeocodingSimple

#### source directory (gmaps)

## Grid Edit

- (demo) GridEdit

#### source directory (gridedit)

## Grid Test

### Demo of grid control

- (demo) GridTest

#### source directory (gridtest)

## GWT Canvas

### Port of GWTCanvas Example

- (demo) GWTCanvasDemo

#### source directory (gwtcanvas)

## Hang man

### Guess the word or be hanged

- (demo) HangMan

#### source directory (hangman)

## helloworld

### Port of GWT hello world example

- (demo) Hello

#### source directory (helloworld)

## helloworld w/bootsplash

### Port of GWT hello world example, with a JS bootsplash

- (demo) Hello

#### source directory (helloworldsplash)

## infohierarchy

### infohierarchy example

- (demo) InfoDirectory

#### source directory (infohierarchy)

## jsimport

### JS import example

- (demo) examplejs

#### source directory (jsimport)

## TestRect and TestDict

### Import of javascript

- (demo) TestDict
- (demo) TestRect

#### source directory (jsobject)

## JSONRPCExample

### JSONRPC example

- (demo) JSONRPCExample

#### source directory (jsonrpc)

## kitchensink

### KitchenSink example

- (demo) KitchenSink

#### source directory (kitchensink)

## libtest

### libtest example

- (demo) LibTest

#### source directory (libtest)

## lightout

### lightout example

- (demo) lightout

#### source directory (lightout)

## mail

### Mail showcase example

- (demo) Mail

#### source directory (mail)

## Map Area Demo

### (unknown)

- (demo) MapAreaDemo

#### source directory (maparea)

## minesweeper

### minesweeper example

- (demo) minesweeper

#### source directory (minesweeper)

## navigate

### navigation based on History class (url)

- (demo) Navigate

#### source directory (navigate)

## OnClickTest

### OnClickTest example

- (demo) OnClickTest

#### source directory (onclicktest)

## picasaweb

### Access RESTful services such as google provide with their gdata api

- (demo) PicasaWeb

#### source directory (picasaweb)

## raphael

### Raphael JS wrapper example

- (demo) events
- (demo) graffle
- (demo) spinner

#### source directory (raphael)

## shell

### Shell / Window example

- (demo) Shell

#### source directory (shell)

## showcase

### Showcase example

- (demo) Showcase

#### source directory (showcase)

## slideshow

### Slideshow example

- (demo) Slideshow

#### source directory (slideshow)

## splitpanel

### Split Panels example

- (demo) SplitPanel

#### source directory (splitpanel)

## svgtest

### svg test example

- (demo) svg_test

#### source directory (svgtest)

## tabpanelwidget

### Tab Panel example

- (demo) Tabs

#### source directory (tabpanelwidget)

## timerdemo

### timerdemo example

- (demo) timerdemo

#### source directory (timerdemo)

## timesheet

### Timesheet MVC example

- (demo) TimeSheet

#### source directory (timesheet)

## Toggle

### Toggle example

- (demo) Toggle

#### source directory (toggle)

## uitest

### uitest example

- (demo) uitest

#### source directory (uitest)

## Widgets

### Widgets example

- (demo) Widgets

#### source directory (widgets)

## xmldoc

### XML doc example

- (demo) XMLload

#### source directory (xmldoc)

#### Pyjs.org